using PokemonSleepWeb.Client.Pages;
using PokemonSleepWeb.Components;
using PokemonSleepWeb.Service;
using PokemonSleepWeb.Service.IService;
using PokemonSleepWeb.Utility;

var builder = WebApplication.CreateBuilder(args);

// Add services to the container.
builder.Services.AddRazorComponents()
    .AddInteractiveServerComponents()
    .AddInteractiveWebAssemblyComponents();

builder.Services.AddControllersWithViews();
builder.Services.AddHttpContextAccessor();
builder.Services.AddHttpClient();

builder.Services.AddHttpClient<IPokemonService, PokemonService>();

StaticDetails.PokemonSleepAPIBase = builder.Configuration["ServiceUrls:PokemonAPI"];


builder.Services.AddScoped<IBaseService, BaseService>();
builder.Services.AddScoped<IPokemonService, PokemonService>();






var app = builder.Build();

// Configure the HTTP request pipeline.
if (app.Environment.IsDevelopment())
{
    app.UseWebAssemblyDebugging();
}
else
{
    app.UseExceptionHandler("/Error", createScopeForErrors: true);
    // The default HSTS value is 30 days. You may want to change this for production scenarios, see https://aka.ms/aspnetcore-hsts.
    app.UseHsts();
}

app.UseHttpsRedirection();

app.UseStaticFiles();
app.UseAntiforgery();

app.MapRazorComponents<App>()
    .AddInteractiveServerRenderMode()
    .AddInteractiveWebAssemblyRenderMode()
    .AddAdditionalAssemblies(typeof(PokemonSleepWeb.Client._Imports).Assembly);

app.Run();
